@@ -21,6 +21,9 @@
 # *  e-mail address 'scipion@cnb.csic.es'
 # *
 # **************************************************************************
+import logging
+logger = logging.getLogger(__name__)
+
 import contextlib
 import sys
 import os
@@ -142,7 +145,7 @@ class UtcConverter:
 to_utc = UtcConverter()
 
 def prettyLog(msg):
-    print(cyan(prettyTime(datetime.now(), secs=True)), msg)
+    logger.info(cyanStr(msg))
 
 
 class Timer(object):
@@ -158,7 +161,7 @@ class Timer(object):
         return datetime.now() - self._dt
 
     def toc(self, message='Elapsed:'):
-        print(message, self.getElapsedTime())
+        logger.info(message + str(self.getElapsedTime()))
 
     def getToc(self):
         return prettyDelta(self.getElapsedTime())
@@ -171,13 +174,14 @@ class Timer(object):
 
 
 def timeit(func):
-    """ Decorator function to have a simple measurement
-    of the execution time of a given function.
-    Just use:
-    @timeit
-    def func(...)
-        ...
-    to use it.
+    """
+    Decorator function to have a simple measurement of the execution time of a given function.
+    To use it ::
+
+        @timeit
+        def func(...)
+            ...
+
     """
 
     def timedFunc(*args, **kwargs):
@@ -246,14 +250,15 @@ def getUniqueItems(originalList):
 
 
 def executeRemoteX(command, hostName, userName, password):
-    """ Execute a remote command with X11 forwarding.
-    Params:
-        command: Command to execute.
-        hostName: Remote host name.
-        userName: User name.
-        password: Password.
-    Returns: 
-        Tuple with standard output and error output.
+    """
+    Execute a remote command with X11 forwarding. Currently not used.
+
+    :param command: Command to execute.
+    :param hostName: Remote host name.
+    :param userName: User name.
+    :param password: Password.
+
+    :returns Tuple with standard output and error output.
     """
     scriptPath = os.path.abspath(os.path.join(os.path.dirname(__file__), "sshAskPass.sh"))
     pswCommand = "echo '" + password + "' | " + scriptPath + " ssh -X " + userName + "@" + hostName + " " + command
@@ -264,14 +269,14 @@ def executeRemoteX(command, hostName, userName, password):
 
 
 def executeRemote(command, hostName, userName, password):
-    """ Execute a remote command.
-    Params:
-        command: Command to execute.
-        hostName: Remote host name.
-        userName: User name.
-        password: Password.
-    Returns: 
-        Tuple with standard input, standard output and error output.
+    """ Execute a remote command. Currently not used
+
+    :param command: Command to execute.
+    :param hostName: Remote host name.
+    :param userName: User name.
+    :param password: Password.
+
+    :returns Tuple with standard input, standard output and error output.
     """
     import paramiko
     ssh = paramiko.SSHClient()
@@ -285,13 +290,14 @@ def executeRemote(command, hostName, userName, password):
 
 def executeLongRemote(command, hostName, userName, password):
     """ Execute a remote command.
-    Params:
-        command: Command to execute.
-        hostName: Remote host name.
-        userName: User name.
-        password: Password.
-    Returns: 
-        Tuple with standard input, standard output and error output.
+
+    :param command: Command to execute.
+    :param hostName: Remote host name.
+    :param userName: User name.
+    :param password: Password.
+
+    :returns Tuple with standard input, standard output and error output.
+
     """
     import paramiko
     import select
@@ -337,22 +343,27 @@ def getHostFullName():
 # ******************************File utils *******************************
 
 def isInFile(text, filePath):
-    """ Checks if given text is in the given file.
-    params:
-        text: Text to check.
-        filePath : File path to check.
-    returns: True if the given text is in the given file, 
-             False if it is not in the file.
+    """
+    Checks if given text is in the given file.
+
+    :param text: Text to check.
+    :param filePath: File path to check.
+
+    :returns True if the given text is in the given file,
+        False if it is not in the file.
+
     """
     return any(text in line for line in open(filePath))
 
 
 def getLineInFile(text, fileName):
     """ Find the line where the given text is located in the given file.
-    params:
-       text: Text to check.
-       filePath : File path to check.
-    returns: File number where the text was located.
+
+    :param text: Text to check.
+    :param filePath: File path to check.
+
+    :return line number where the text was located.
+
     """
     with open(fileName) as f:
         for i, line in enumerate(f):
@@ -388,12 +399,12 @@ class StrColors(Enum):
 
 def getColorStr(text, color, bold=False):
     """ Add ANSI color codes to the string if there is a terminal sys.stdout.
-    Params:
-     text: text to be colored
-     color: red or green
-     bold: bold the text
+
+    :param text: text to be colored
+    :param color: red or green
+    :param bold: bold the text
     """
-    if envVarOn('SCIPION_SAFE_COLORS') and not sys.stdout.isatty():
+    if not Config.colorsInTerminal():
         return text
 
     attr = [str(color.value)]
@@ -441,15 +452,15 @@ blackB, redB, greenB, yellowB, blueB, magentaB, cyanB, whiteB = [
     ansi(i, bold=True) for i in range(30, 38)]
 
 # -------------- Hyper text highlighting ----------------------------
-"""
-We use a subset of TWiki hyper text conventions.
-In particular:
-    *some_text* will display some_text in bold
-    _some_text_ will display some_text in italic
-    Links:
-        http://www.link-page.com  -> hyperlink using the url as label
-        [[http://www.link-page.com][Link page]] -> hyperlink using "Link page" as label
-"""
+#
+# We use a subset of TWiki hyper text conventions.
+# In particular:
+#     *some_text* will display some_text in bold
+#     _some_text_ will display some_text in italic
+#     Links:
+#         http://www.link-page.com  -> hyperlink using the url as label
+#         [[http://www.link-page.com][Link page]] -> hyperlink using "Link page" as label
+
 # Types of recognized styles
 HYPER_BOLD = 'bold'
 HYPER_ITALIC = 'italic'
@@ -481,11 +492,11 @@ HYPER_ALL_RE = re.compile(PATTERN_ALL)
 
 def parseHyperText(text, matchCallback):
     """ Parse the text recognizing Hyper definitions below.
-    Params:
-        matchCallback: a callback function to processing each matching,
-                       it should accept the type of match (HYPER_BOLD, ITALIC or LINK)
-    Return:
-        The input text with the replacements made by matchCallback
+
+    :param matchCallback: a callback function to processing each matching,
+        it should accept the type of match (HYPER_BOLD, ITALIC or LINK)
+
+    :return The input text with the replacements made by matchCallback
     """
 
     def _match(match):
@@ -665,21 +676,21 @@ class Environ(dict):
                 return self.get(k)
 
         if mandatory:
-            print("None of the variables: %s found in the Environment. "
+            logger.info("None of the variables: %s found in the Environment. "
                   "Please check scipion.conf files." % (str(keys)))
 
         return None
 
     def set(self, varName, varValue, position=REPLACE):
         """ Modify the value for some variable.
-        Params:
-            varName: for example LD_LIBRARY_PATH
-            varValue: the value to add or replace.
-            position: controls how the value will be changed.
-                If REPLACE, it will overwrite the value of
-                the var.
-                BEGIN or END will preserve the current value
-                and add (at begin or end) the new value.
+
+        :param varName: for example LD_LIBRARY_PATH
+        :param varValue: the value to set, prefix or suffix.
+        :param position: controls how the value will be changed.
+            If REPLACE, it will overwrite the value of
+            the var. BEGIN or END will preserve the current value
+            and will add, at the beginning or end, the new value.
+
         """
         if varName in self and position != self.REPLACE:
             if position == self.BEGIN:
@@ -704,7 +715,7 @@ class Environ(dict):
         if existsVariablePaths(libraryPath):
             self.update({'LD_LIBRARY_PATH': libraryPath}, position=position)
         else:
-            print("Some paths do not exist in: % s" % libraryPath)
+            logger.info("Some paths do not exist in: % s" % libraryPath)
 
     def setPrepend(self, prepend):
         """ Use this method to set a prepend string that will be added at
@@ -744,6 +755,7 @@ def envVarOn(varName, env=None):
     return strToBoolean(v)
 
 def strToBoolean(string):
+    """ Converts a string into a Boolean if the string is on of true, yes, on, 1. Case insensitive."""
     return string is not None and string.lower() in ['true', 'yes', 'on', '1']
 
 
@@ -753,27 +765,15 @@ def getMemoryAvailable():
     return virtual_memory().total // 1024 ** 2
 
 
-def startDebugger(password='a'):
-    if Config.debugOn():
-        try:
-            # FIXME: rpdb2 does not support python 3
-            from rpdb2 import start_embedded_debugger
-            print("Starting debugger...")
-            start_embedded_debugger(password)
-        except Exception:
-            print("Error importing rpdb2 debugging module, consider installing winpdb.")
-
-
 def getFreePort(basePort=0, host=''):
     import socket
-    port = 0
     try:
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         s.bind((host, basePort))
         ipaddr, port = s.getsockname()
         s.close()
     except Exception as e:
-        print(e)
+        logger.error("Can't get a free port", exc_info=e)
         return 0
     return port
 
@@ -802,7 +802,7 @@ def hex_to_rgb(value):
 
 
 def rgb_to_hex(rgb):
-    return '#%02x%02x%02x' % rgb
+    return '#%02x%02x%02x' % (int(rgb[0]), int(rgb[1]), int(rgb[2]))
 
 
 def lighter(color, percent):
@@ -849,16 +849,19 @@ def getEnvVariable(variableName, default=None, exceptionMsg=None):
 @contextlib.contextmanager
 def weakImport(package):
     """
-    This method can be use to tolerate imports that may fail, e.g imports
+    This method can be used to tolerate imports that may fail.
 
-    from .protocol_ctffind import CistemProtCTFFind
-    with weakImport('tomo'):
-        from .protocol_ts_ctffind import CistemProtTsCtffind
+    e.g::
 
-    in this case CistemProtTsCtffind should fail if tomo package is missing,
+        from .protocol_ctffind import CistemProtCTFFind
+        with weakImport('tomo'):
+            from .protocol_ts_ctffind import CistemProtTsCtffind
+
+    In this case CistemProtTsCtffind should fail if tomo package is missing,
     but exception is captured and all the imports above should be available
 
     :param package: name of the package that is expected to fail
+
     """
     try:
         yield
